
import copy



def loadStones(filename):
    """ 
        load stones from given file. Each line contains description of one stone.
        Each stone is described as: x1 y1 x2 y2 ... x_n y_n
        This function returns array of array, i.e:
        [ [ x1, y1], [x2, y2],  ..., [xn, yn ] ]
    """
    f = open(filename,"r")
    result = []

    for line in f:
        line = line.strip()
        vv = list(map(int, line.split()))
        if (len(vv) % 2) != 0:
            print("Wrong stone at line: '", line, "', number of x,y must be even!");
            quit()
        pieces = [];
        for j in range(len(vv) // 2):
            x = vv[2*j+0];
            y = vv[2*j+1];
            pieces.append([x,y])
        result.append( pieces );
    print("Loaded ", len(result) , "stones from", filename);
    return result;


class BasePlayer:
    """
        basic class for the player. 
        
        !!! DO NOT MODIFY THIS CLASS !!!

        board notation:
        self.board[r][c] = 1: cell at row 'r' and column 'c' belongs to a piece/stone of player 1
        self.board[r][c] = -1: cell at row 'r' and column 'c' belongs to a piece/stone of player 2
        self.board[r][c] = 0: cell is not occupied.

        OTHER values at self.board are not accepted (this will be controlled by BRUTE). So write there
        only 0 or 1 or -1.

        player1 (it markes it's stones by '1') starts are r=1, c=1, i.e., at self.board[0][0]
        player2 (it markes it's stones by '-1') starts are r=size-1, c=size-1, i.e., at self.board[self.rows-1][self.cols-1]
        
    """
    def __init__(self, name, sizex, sizey, which, stones):
        self.name = name;         #student's name, will be filled by BRUTE
        self.text = "basicPlayer" #student' debug info, e.g. version, name of algorithm..
        self.cols = sizex;        #number of columns of the board
        self.rows = sizey;        #number of rows of the board
        self.which = which;       #1=player1, -1=player2
        self.stones = copy.deepcopy(stones)

        #grid[row][col]: 0=empty, 1=player1, -1=player2
        self.board = []
        for row in range(self.rows):
            self.board.append( [] );
            for col in range(self.cols):
                self.board[row].append(0);

        #count number of pieces that are available (aka total stone-area)
        self.totalPieces = 0;
        for i in range(len(self.stones)):
            self.totalPieces += len(self.stones[i]);

    def getScore(self, which):
        """
            return score which is the number of pieces/cells that were NOT placed by the given player 
        """
        count = 0;
        for r in range(self.rows):
            for c in range(self.cols):
                if (self.board[r][c] == which):
                    count+=1
        return self.totalPieces - count;

    def move(self):
        """
        DEFINE YOUR STRATEGY HERE
        return list or [x,y] coordinates where some piece will be placed.
        e.g. to place one-cell piece into position 12,10, return [ [12,10] ];

        return [] if no piece can be placed
        """
        print("Base move");

        return [];
        
    def update(self, occupiedCells):
        """ 
        otherPieces = list of [x,y] coordinates where the opponent placed its piece. This player fills it with the
        color of the oponent

        it is ensured that otherPieces[] contains valid coordinates, i.e., inside the grid, defining valid piece at valid position
        """

        other = -self.which; #color of the opponent
        for i in range(len(occupiedCells)):
            x = occupiedCells[i][0];
            y = occupiedCells[i][1];
            self.board[y][x] = other;

    def print(self):
        print("Board of player", self.which, self.name, "----");
        print("   ",end="");
        for col in range(self.cols):
            print("{0:3}".format(col), end="");
        print()
        for row in range(len(self.board)-1,-1, -1):
            print("{0:2} |".format(row), end="");
            for col in range(len(self.board[row])):
                str = " . "
                if (self.board[row][col] == 1):
                    str = " A ";
                elif (self.board[row][col] == -1):
                    str = " B ";
                print(str,end="");
            print()


